@@ -1,6 +1,6 @@
 from typing import Any, Tuple
 
-from pandas.core.series import Series
+from pandas import Series
 
 from ..caller_base import CallerBase
 from ..error.client_only_endpoint import client_only_endpoint
@@ -8,12 +8,14 @@ from ..error.illegal_attr_checker import IllegalAttrChecker
 from ..server_version.compatible_with import compatible_with
 from ..server_version.server_version import ServerVersion
 from .graph_object import Graph
+from .graph_type_check import from_graph_type_check
 
 
 class GraphSampleRunner(CallerBase, IllegalAttrChecker):
     @client_only_endpoint("gds.alpha.graph.sample")
     @compatible_with("construct", min_inclusive=ServerVersion(2, 2, 0))
-    def rwr(self, graph_name: str, from_G: Graph, **config: Any) -> Tuple[Graph, Series]:
+    @from_graph_type_check
+    def rwr(self, graph_name: str, from_G: Graph, **config: Any) -> Tuple[Graph, "Series[Any]"]:
         self._namespace += ".rwr"
 
         query = f"CALL {self._namespace}($graph_name, $from_graph_name, $config)"
