@@ -1,11 +1,10 @@
 from abc import ABC, abstractmethod
 from typing import Any, Dict
 
-import pandas
-from pandas.core.frame import DataFrame
-from pandas.core.series import Series
+from pandas import DataFrame, Series
 
 from ..graph.graph_object import Graph
+from ..graph.graph_type_check import graph_type_check
 from ..query_runner.query_runner import QueryRunner
 from ..server_version.server_version import ServerVersion
 
@@ -31,7 +30,7 @@ class Model(ABC):
 
         return info
 
-    def _estimate_predict(self, predict_mode: str, graph_name: str, config: Dict[str, Any]) -> Series:
+    def _estimate_predict(self, predict_mode: str, graph_name: str, config: Dict[str, Any]) -> "Series[Any]":
         query = f"{self._query_prefix()}{predict_mode}.estimate($graph_name, $config)"
         config["modelName"] = self.name()
         params = {"graph_name": graph_name, "config": config}
@@ -44,11 +43,13 @@ class Model(ABC):
     def type(self) -> str:
         return self._list_info()["modelInfo"][0]["modelType"]  # type: ignore
 
-    def train_config(self) -> Series:
-        return pandas.Series(self._list_info()["trainConfig"][0])
+    def train_config(self) -> "Series[Any]":
+        train_config: "Series[Any]" = Series(self._list_info()["trainConfig"][0])
+        return train_config
 
-    def graph_schema(self) -> Series:
-        return pandas.Series(self._list_info()["graphSchema"][0])
+    def graph_schema(self) -> "Series[Any]":
+        graph_schema: "Series[Any]" = Series(self._list_info()["graphSchema"][0])
+        return graph_schema
 
     def loaded(self) -> bool:
         return self._list_info()["loaded"].squeeze()  # type: ignore
@@ -68,16 +69,18 @@ class Model(ABC):
 
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def drop(self, failIfMissing: bool = False) -> Series:
+    def drop(self, failIfMissing: bool = False) -> "Series[Any]":
         query = "CALL gds.beta.model.drop($model_name, $fail_if_missing)"
         params = {"model_name": self._name, "fail_if_missing": failIfMissing}
 
         return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
-    def metrics(self) -> Series:
+    def metrics(self) -> "Series[Any]":
         model_info = self._list_info()["modelInfo"][0]
-        return pandas.Series(model_info["metrics"])
+        metrics: "Series[Any]" = Series(model_info["metrics"])
+        return metrics
 
+    @graph_type_check
     def predict_stream(self, G: Graph, **config: Any) -> DataFrame:
         query = f"{self._query_prefix()}stream($graph_name, $config)"
         config["modelName"] = self.name()
@@ -85,15 +88,24 @@ class Model(ABC):
 
         return self._query_runner.run_query_with_logging(query, params)
 
-    def predict_stream_estimate(self, G: Graph, **config: Any) -> Series:
+    @graph_type_check
+    def predict_stream_estimate(self, G: Graph, **config: Any) -> "Series[Any]":
         return self._estimate_predict("stream", G.name(), config)
 
-    def predict_mutate(self, G: Graph, **config: Any) -> Series:
+    @graph_type_check
+    def predict_mutate(self, G: Graph, **config: Any) -> "Series[Any]":
         query = f"{self._query_prefix()}mutate($graph_name, $config)"
         config["modelName"] = self.name()
         params = {"graph_name": G.name(), "config": config}
 
         return self._query_runner.run_query_with_logging(query, params).squeeze()  # type: ignore
 
-    def predict_mutate_estimate(self, G: Graph, **config: Any) -> Series:
+    @graph_type_check
+    def predict_mutate_estimate(self, G: Graph, **config: Any) -> "Series[Any]":
         return self._estimate_predict("mutate", G.name(), config)
+
+    def __str__(self) -> str:
+        return f"{self.__class__.__name__}(name={self.name()}, type={self.type()})"
+
+    def __repr__(self) -> str:
+        return f"{self.__class__.__name__}({self._list_info().to_dict()})"
